@@ -62,8 +62,8 @@ typedef struct
 static void Usage()
 
 {
-    printf("Usage: gdalenhance [--help-general]\n"
-           "       [-of format] [-co \"NAME=VALUE\"]*\n"
+    printf("Usage: gdalenhance [--help] [--help-general]\n"
+           "       [-of <format>] [-co <NAME>=<VALUE>]...\n"
            "       [-ot {Byte/Int16/UInt16/UInt32/Int32/Float32/Float64/\n"
            "             CInt16/CInt32/CFloat32/CFloat64}]\n"
            //            "       [-src_scale[_n] src_min src_max]\n"
@@ -72,8 +72,8 @@ static void Usage()
            //            "       [-s_nodata[_n] value]\n"
            //            "       [-stddev multiplier]\n"
            "       [-equalize]\n"
-           "       [-config filename]\n"
-           "       src_dataset dst_dataset\n\n");
+           "       [-config <filename>]\n"
+           "       <src_dataset> <dst_dataset>\n\n");
     printf("%s\n\n", GDALVersionInfo("--version"));
     exit(1);
 }
@@ -125,6 +125,10 @@ MAIN_START(argc, argv)
                    argv[0], GDAL_RELEASE_NAME, GDALVersionInfo("RELEASE_NAME"));
             return 0;
         }
+        else if (EQUAL(argv[i], "--help"))
+        {
+            Usage();
+        }
         else if (i < argc - 1 &&
                  (EQUAL(argv[i], "-of") || EQUAL(argv[i], "-f")))
         {
