@@ -38,70 +38,73 @@
 /*                           BASISUDataset                              */
 /************************************************************************/
 
-class BASISUDataset final: public GDALPamDataset
+class BASISUDataset final : public GDALPamDataset
 {
     friend class BASISURasterBand;
 
     basist::basisu_transcoder m_transcoder{};
-    basist::basisu_transcoder& m_transcoderRef;
-    bool                    m_bHasDecodeRun = false;
-    void*                   m_pEncodedData = nullptr;
-    uint32_t                m_nEncodedDataSize = 0;
-    void*                   m_pDecodedData = nullptr;
-    uint32_t                m_nLineStride = 0;
-    BASISUDataset*          m_poParent = nullptr;
-    uint32_t                m_iImageIdx = 0;
-    uint32_t                m_iLevel = 0;
+    basist::basisu_transcoder &m_transcoderRef;
+    bool m_bHasDecodeRun = false;
+    void *m_pEncodedData = nullptr;
+    uint32_t m_nEncodedDataSize = 0;
+    void *m_pDecodedData = nullptr;
+    uint32_t m_nLineStride = 0;
+    BASISUDataset *m_poParent = nullptr;
+    uint32_t m_iImageIdx = 0;
+    uint32_t m_iLevel = 0;
     std::vector<std::unique_ptr<BASISUDataset>> m_apoOverviewsDS{};
 
-    void*                   GetDecodedData(uint32_t& nLineStride);
+    void *GetDecodedData(uint32_t &nLineStride);
 
     CPL_DISALLOW_COPY_ASSIGN(BASISUDataset)
 
-public:
-                            ~BASISUDataset() override;
-                            BASISUDataset(uint32_t iImageIdx,
-                                          void* pEncodedData,
-                                          uint32_t nEncodedDataSize);
-                            BASISUDataset(BASISUDataset* poParent, uint32_t iLevel);
-    static int              Identify(GDALOpenInfo* poOpenInfo);
-    static GDALDataset*     Open(GDALOpenInfo* poOpenInfo);
-    static GDALDataset*     CreateCopy(const char * pszFilename, GDALDataset *poSrcDS,
-                                       int bStrict, char ** papszOptions,
-                                       GDALProgressFunc pfnProgress, void * pProgressData);
+  public:
+    ~BASISUDataset() override;
+    BASISUDataset(uint32_t iImageIdx, void *pEncodedData,
+                  uint32_t nEncodedDataSize);
+    BASISUDataset(BASISUDataset *poParent, uint32_t iLevel);
+    static int Identify(GDALOpenInfo *poOpenInfo);
+    static GDALDataset *Open(GDALOpenInfo *poOpenInfo);
+    static GDALDataset *CreateCopy(const char *pszFilename,
+                                   GDALDataset *poSrcDS, int bStrict,
+                                   char **papszOptions,
+                                   GDALProgressFunc pfnProgress,
+                                   void *pProgressData);
 };
 
 /************************************************************************/
 /*                          BASISURasterBand                            */
 /************************************************************************/
 
-class BASISURasterBand final: public GDALPamRasterBand
+class BASISURasterBand final : public GDALPamRasterBand
 {
-protected:
-    CPLErr              IReadBlock(int nBlockXOff, int nBlockYOff, void* pImage) override;
-public:
-                        BASISURasterBand(BASISUDataset* poDSIn, int nBandIn);
+  protected:
+    CPLErr IReadBlock(int nBlockXOff, int nBlockYOff, void *pImage) override;
 
-    int                 GetOverviewCount() override;
-    GDALRasterBand*     GetOverview(int nIdx) override;
+  public:
+    BASISURasterBand(BASISUDataset *poDSIn, int nBandIn);
+
+    int GetOverviewCount() override;
+    GDALRasterBand *GetOverview(int nIdx) override;
 };
 
 /************************************************************************/
 /*                                Identify()                            */
 /************************************************************************/
 
-int BASISUDataset::Identify(GDALOpenInfo* poOpenInfo)
+int BASISUDataset::Identify(GDALOpenInfo *poOpenInfo)
 {
-    if( STARTS_WITH(poOpenInfo->pszFilename, "BASISU:") )
+    if (STARTS_WITH(poOpenInfo->pszFilename, "BASISU:"))
         return true;
-    // See https://github.com/BinomialLLC/basis_universal/blob/master/spec/basis_spec.txt
+    // See
+    // https://github.com/BinomialLLC/basis_universal/blob/master/spec/basis_spec.txt
     constexpr int HEADER_SIZE = 77;
-    if( !(poOpenInfo->fpL != nullptr &&
+    if (!(poOpenInfo->fpL != nullptr &&
           poOpenInfo->nHeaderBytes >= HEADER_SIZE &&
-          poOpenInfo->pabyHeader[0] == 0x73 && // Signature
-          poOpenInfo->pabyHeader[1] == 0x42 && // Signature
-          poOpenInfo->pabyHeader[4] == HEADER_SIZE && // Header size
-          poOpenInfo->pabyHeader[5] == 0) )  // Header size
+          poOpenInfo->pabyHeader[0] == 0x73 &&         // Signature
+          poOpenInfo->pabyHeader[1] == 0x42 &&         // Signature
+          poOpenInfo->pabyHeader[4] == HEADER_SIZE &&  // Header size
+          poOpenInfo->pabyHeader[5] == 0))             // Header size
     {
         return false;
     }
@@ -116,12 +119,10 @@ int BASISUDataset::Identify(GDALOpenInfo* poOpenInfo)
 /*                           BASISUDataset()                            */
 /************************************************************************/
 
-BASISUDataset::BASISUDataset(uint32_t iImageIdx, void* pEncodedData,
-                             uint32_t nEncodedDataSize):
-    m_transcoderRef(m_transcoder),
-    m_pEncodedData(pEncodedData),
-    m_nEncodedDataSize(nEncodedDataSize),
-    m_iImageIdx(iImageIdx)
+BASISUDataset::BASISUDataset(uint32_t iImageIdx, void *pEncodedData,
+                             uint32_t nEncodedDataSize)
+    : m_transcoderRef(m_transcoder), m_pEncodedData(pEncodedData),
+      m_nEncodedDataSize(nEncodedDataSize), m_iImageIdx(iImageIdx)
 {
 }
 
@@ -129,16 +130,14 @@ BASISUDataset::BASISUDataset(uint32_t iImageIdx, void* pEncodedData,
 /*                           BASISUDataset()                            */
 /************************************************************************/
 
-BASISUDataset::BASISUDataset(BASISUDataset* poParent, uint32_t iLevel):
-    m_transcoderRef(poParent->m_transcoderRef),
-    m_poParent(poParent),
-    m_iImageIdx(poParent->m_iImageIdx),
-    m_iLevel(iLevel)
+BASISUDataset::BASISUDataset(BASISUDataset *poParent, uint32_t iLevel)
+    : m_transcoderRef(poParent->m_transcoderRef), m_poParent(poParent),
+      m_iImageIdx(poParent->m_iImageIdx), m_iLevel(iLevel)
 {
     basist::basisu_image_level_info level_info;
     CPL_IGNORE_RET_VAL(m_transcoderRef.get_image_level_info(
-        m_poParent->m_pEncodedData, m_poParent->m_nEncodedDataSize,
-        level_info, m_iImageIdx, m_iLevel));
+        m_poParent->m_pEncodedData, m_poParent->m_nEncodedDataSize, level_info,
+        m_iImageIdx, m_iLevel));
     nRasterXSize = static_cast<int>(level_info.m_orig_width);
     nRasterYSize = static_cast<int>(level_info.m_orig_height);
 }
@@ -157,9 +156,9 @@ BASISUDataset::~BASISUDataset()
 /*                        GetDecodedData()                              */
 /************************************************************************/
 
-void* BASISUDataset::GetDecodedData(uint32_t& nLineStride)
+void *BASISUDataset::GetDecodedData(uint32_t &nLineStride)
 {
-    if( m_bHasDecodeRun )
+    if (m_bHasDecodeRun)
     {
         nLineStride = m_nLineStride;
         return m_pDecodedData;
@@ -171,27 +170,29 @@ void* BASISUDataset::GetDecodedData(uint32_t& nLineStride)
     basist::basisu_image_level_info level_info;
     const auto poRefDS = m_poParent ? m_poParent : this;
     CPL_IGNORE_RET_VAL(m_transcoderRef.get_image_level_info(
-        poRefDS->m_pEncodedData, poRefDS->m_nEncodedDataSize, level_info, m_iImageIdx, m_iLevel));
+        poRefDS->m_pEncodedData, poRefDS->m_nEncodedDataSize, level_info,
+        m_iImageIdx, m_iLevel));
 
-    if( !m_transcoderRef.start_transcoding(poRefDS->m_pEncodedData, poRefDS->m_nEncodedDataSize) )
+    if (!m_transcoderRef.start_transcoding(poRefDS->m_pEncodedData,
+                                           poRefDS->m_nEncodedDataSize))
     {
         CPLError(CE_Failure, CPLE_AppDefined,
                  "basisu_transcoder::start_transcoding() failed!");
         return nullptr;
     }
 
-    m_pDecodedData = VSI_MALLOC3_VERBOSE(level_info.m_orig_width, level_info.m_orig_height, 4);
-    if( m_pDecodedData == nullptr )
+    m_pDecodedData = VSI_MALLOC3_VERBOSE(level_info.m_orig_width,
+                                         level_info.m_orig_height, 4);
+    if (m_pDecodedData == nullptr)
         return nullptr;
 
     constexpr basist::transcoder_texture_format transcoder_tex_fmt =
         basist::transcoder_texture_format::cTFRGBA32;
-    if( !m_transcoderRef.transcode_image_level(
-        poRefDS->m_pEncodedData, poRefDS->m_nEncodedDataSize,
-        m_iImageIdx, m_iLevel,
-        m_pDecodedData,
-        level_info.m_orig_width * level_info.m_orig_height * 4,
-        transcoder_tex_fmt) )
+    if (!m_transcoderRef.transcode_image_level(
+            poRefDS->m_pEncodedData, poRefDS->m_nEncodedDataSize, m_iImageIdx,
+            m_iLevel, m_pDecodedData,
+            level_info.m_orig_width * level_info.m_orig_height * 4,
+            transcoder_tex_fmt))
     {
         CPLError(CE_Failure, CPLE_AppDefined,
                  "basisu_transcoder::transcode_image_level() failed!");
@@ -209,7 +210,7 @@ void* BASISUDataset::GetDecodedData(uint32_t& nLineStride)
 /*                           BASISURasterBand()                         */
 /************************************************************************/
 
-BASISURasterBand::BASISURasterBand(BASISUDataset* poDSIn, int nBandIn)
+BASISURasterBand::BASISURasterBand(BASISUDataset *poDSIn, int nBandIn)
 {
     poDS = poDSIn;
     nBand = nBandIn;
@@ -218,28 +219,26 @@ BASISURasterBand::BASISURasterBand(BASISUDataset* poDSIn, int nBandIn)
     nBlockXSize = nRasterXSize;
     nBlockYSize = 1;
     eDataType = GDT_Byte;
-    SetColorInterpretation(static_cast<GDALColorInterp>(GCI_RedBand + nBandIn - 1));
+    SetColorInterpretation(
+        static_cast<GDALColorInterp>(GCI_RedBand + nBandIn - 1));
 }
 
 /************************************************************************/
 /*                             IReadBlock()                             */
 /************************************************************************/
 
-CPLErr BASISURasterBand::IReadBlock(int /*nBlockXOff*/, int nBlockYOff, void* pImage)
+CPLErr BASISURasterBand::IReadBlock(int /*nBlockXOff*/, int nBlockYOff,
+                                    void *pImage)
 {
-    auto poGDS = cpl::down_cast<BASISUDataset*>(poDS);
+    auto poGDS = cpl::down_cast<BASISUDataset *>(poDS);
     uint32_t nLineStride = 0;
-    void* decoded_data = poGDS->GetDecodedData(nLineStride);
-    if( decoded_data == nullptr )
+    void *decoded_data = poGDS->GetDecodedData(nLineStride);
+    if (decoded_data == nullptr)
         return CE_Failure;
 
-    GDALCopyWords(static_cast<GByte*>(decoded_data) + nBlockYOff * nLineStride + nBand - 1,
-                  GDT_Byte,
-                  4,
-                  pImage,
-                  GDT_Byte,
-                  1,
-                  nBlockXSize);
+    GDALCopyWords(static_cast<GByte *>(decoded_data) +
+                      nBlockYOff * nLineStride + nBand - 1,
+                  GDT_Byte, 4, pImage, GDT_Byte, 1, nBlockXSize);
     return CE_None;
 }
 
@@ -249,7 +248,7 @@ CPLErr BASISURasterBand::IReadBlock(int /*nBlockXOff*/, int nBlockYOff, void* pI
 
 int BASISURasterBand::GetOverviewCount()
 {
-    auto poGDS = cpl::down_cast<BASISUDataset*>(poDS);
+    auto poGDS = cpl::down_cast<BASISUDataset *>(poDS);
     return static_cast<int>(poGDS->m_apoOverviewsDS.size());
 }
 
@@ -257,11 +256,11 @@ int BASISURasterBand::GetOverviewCount()
 /*                             GetOverview()                            */
 /************************************************************************/
 
-GDALRasterBand* BASISURasterBand::GetOverview(int nIdx)
+GDALRasterBand *BASISURasterBand::GetOverview(int nIdx)
 {
-    if( nIdx < 0 || nIdx >= GetOverviewCount() )
+    if (nIdx < 0 || nIdx >= GetOverviewCount())
         return nullptr;
-    auto poGDS = cpl::down_cast<BASISUDataset*>(poDS);
+    auto poGDS = cpl::down_cast<BASISUDataset *>(poDS);
     return poGDS->m_apoOverviewsDS[nIdx]->GetRasterBand(nBand);
 }
 
@@ -269,24 +268,23 @@ GDALRasterBand* BASISURasterBand::GetOverview(int nIdx)
 /*                                Open()                                */
 /************************************************************************/
 
-GDALDataset* BASISUDataset::Open(GDALOpenInfo* poOpenInfo)
+GDALDataset *BASISUDataset::Open(GDALOpenInfo *poOpenInfo)
 {
-    if( !Identify(poOpenInfo) || poOpenInfo->eAccess == GA_Update )
+    if (!Identify(poOpenInfo) || poOpenInfo->eAccess == GA_Update)
         return nullptr;
 
-    VSILFILE* fpL = nullptr;
+    VSILFILE *fpL = nullptr;
     uint32_t nImageIdx = static_cast<uint32_t>(-1);
-    if( STARTS_WITH(poOpenInfo->pszFilename, "BASISU:") )
+    if (STARTS_WITH(poOpenInfo->pszFilename, "BASISU:"))
     {
         const CPLStringList aosTokens(CSLTokenizeString2(
-            poOpenInfo->pszFilename, ":", CSLT_HONOURSTRINGS ));
-        if( aosTokens.size() != 3 )
+            poOpenInfo->pszFilename, ":", CSLT_HONOURSTRINGS));
+        if (aosTokens.size() != 3)
             return nullptr;
         fpL = VSIFOpenL(aosTokens[1], "rb");
-        if( fpL == nullptr )
+        if (fpL == nullptr)
         {
-            CPLError(CE_Failure, CPLE_FileIO,
-                     "Cannot open %s", aosTokens[1]);
+            CPLError(CE_Failure, CPLE_FileIO, "Cannot open %s", aosTokens[1]);
             return nullptr;
         }
         nImageIdx = static_cast<uint32_t>(atoi(aosTokens[2]));
@@ -294,60 +292,58 @@ GDALDataset* BASISUDataset::Open(GDALOpenInfo* poOpenInfo)
     GIntBig nMaxSize = std::strtoull(
         CPLGetConfigOption("BASISU_MAX_FILE_SIZE", "0"), nullptr, 10);
     constexpr GIntBig BASISU_LIMIT = std::numeric_limits<uint32_t>::max();
-    if( nMaxSize == 0 || nMaxSize > BASISU_LIMIT )
+    if (nMaxSize == 0 || nMaxSize > BASISU_LIMIT)
         nMaxSize = BASISU_LIMIT;
-    GByte* pabyRet = nullptr;
+    GByte *pabyRet = nullptr;
     vsi_l_offset nSizeLarge = 0;
-    int nRet = VSIIngestFile(fpL ? fpL : poOpenInfo->fpL, nullptr,
-                             &pabyRet, &nSizeLarge,
-                             nMaxSize);
-    if( fpL != nullptr )
+    int nRet = VSIIngestFile(fpL ? fpL : poOpenInfo->fpL, nullptr, &pabyRet,
+                             &nSizeLarge, nMaxSize);
+    if (fpL != nullptr)
         VSIFCloseL(fpL);
-    if( !nRet )
+    if (!nRet)
     {
         return nullptr;
     }
     const uint32_t nSize = static_cast<uint32_t>(nSizeLarge);
 
     auto poDS = cpl::make_unique<BASISUDataset>(
-        nImageIdx != static_cast<uint32_t>(-1) ? nImageIdx : 0,
-        pabyRet, nSize);
-    auto& transcoder = poDS->m_transcoder;
+        nImageIdx != static_cast<uint32_t>(-1) ? nImageIdx : 0, pabyRet, nSize);
+    auto &transcoder = poDS->m_transcoder;
     basist::basisu_file_info file_info;
-    if( !transcoder.get_file_info(pabyRet, nSize, file_info) )
+    if (!transcoder.get_file_info(pabyRet, nSize, file_info))
     {
         CPLError(CE_Failure, CPLE_AppDefined,
                  "basisu_transcoder::get_file_info() failed! "
                  "File either uses an unsupported feature or is invalid");
         return nullptr;
     }
-    if( nImageIdx == static_cast<uint32_t>(-1) && file_info.m_total_images > 1 )
+    if (nImageIdx == static_cast<uint32_t>(-1) && file_info.m_total_images > 1)
     {
         CPLStringList aosSubdatasets;
-        for( uint32_t iImageIdx = 0; iImageIdx < file_info.m_total_images; ++iImageIdx )
+        for (uint32_t iImageIdx = 0; iImageIdx < file_info.m_total_images;
+             ++iImageIdx)
         {
             aosSubdatasets.SetNameValue(
                 CPLSPrintf("SUBDATASET_%d_NAME", iImageIdx + 1),
-                CPLSPrintf("BASISU:\"%s\":%u",
-                           poOpenInfo->pszFilename,
+                CPLSPrintf("BASISU:\"%s\":%u", poOpenInfo->pszFilename,
                            iImageIdx));
             aosSubdatasets.SetNameValue(
                 CPLSPrintf("SUBDATASET_%d_DESC", iImageIdx + 1),
-                CPLSPrintf("Image %u of %s",
-                           iImageIdx,
+                CPLSPrintf("Image %u of %s", iImageIdx,
                            poOpenInfo->pszFilename));
         }
         poDS->nRasterXSize = 0;
         poDS->nRasterYSize = 0;
         poDS->SetMetadata(aosSubdatasets.List(), "SUBDATASETS");
 
-        poDS->SetPamFlags( poDS->GetPamFlags() & ~GPF_DIRTY );
+        poDS->SetPamFlags(poDS->GetPamFlags() & ~GPF_DIRTY);
 
         return poDS.release();
     }
 
     basist::basisu_image_info image_info;
-    if( !transcoder.get_image_info(pabyRet, nSize, image_info, poDS->m_iImageIdx) )
+    if (!transcoder.get_image_info(pabyRet, nSize, image_info,
+                                   poDS->m_iImageIdx))
     {
         CPLError(CE_Failure, CPLE_AppDefined,
                  "basisu_transcoder::get_image_info() failed");
@@ -356,7 +352,7 @@ GDALDataset* BASISUDataset::Open(GDALOpenInfo* poOpenInfo)
     poDS->nRasterXSize = static_cast<int>(image_info.m_orig_width);
     poDS->nRasterYSize = static_cast<int>(image_info.m_orig_height);
 
-    switch( file_info.m_tex_format )
+    switch (file_info.m_tex_format)
     {
         case basist::basis_tex_format::cETC1S:
             poDS->SetMetadataItem("COMPRESSION", "ETC1S", "IMAGE_STRUCTURE");
@@ -367,32 +363,34 @@ GDALDataset* BASISUDataset::Open(GDALOpenInfo* poOpenInfo)
     }
 
     const int l_nBands = 3 + (image_info.m_alpha_flag ? 1 : 0);
-    for( int i = 1; i <= l_nBands; ++i )
+    for (int i = 1; i <= l_nBands; ++i)
     {
         poDS->SetBand(i, new BASISURasterBand(poDS.get(), i));
     }
 
     const uint32_t nLevels = file_info.m_image_mipmap_levels[poDS->m_iImageIdx];
-    for( uint32_t level_index = 1; level_index < nLevels; ++level_index )
+    for (uint32_t level_index = 1; level_index < nLevels; ++level_index)
     {
         basist::basisu_image_level_info level_info;
-        if( transcoder.get_image_level_info(pabyRet, nSize, level_info,
-                                            poDS->m_iImageIdx, level_index) )
+        if (transcoder.get_image_level_info(pabyRet, nSize, level_info,
+                                            poDS->m_iImageIdx, level_index))
         {
-            auto poOverviewDS = cpl::make_unique<BASISUDataset>(poDS.get(), level_index);
-            for( int i = 1; i <= l_nBands; ++i )
+            auto poOverviewDS =
+                cpl::make_unique<BASISUDataset>(poDS.get(), level_index);
+            for (int i = 1; i <= l_nBands; ++i)
             {
-                poOverviewDS->SetBand(i, new BASISURasterBand(poOverviewDS.get(), i));
+                poOverviewDS->SetBand(
+                    i, new BASISURasterBand(poOverviewDS.get(), i));
             }
             poDS->m_apoOverviewsDS.emplace_back(std::move(poOverviewDS));
         }
     }
 
-    poDS->SetPamFlags( poDS->GetPamFlags() & ~GPF_DIRTY );
+    poDS->SetPamFlags(poDS->GetPamFlags() & ~GPF_DIRTY);
 
     // Initialize any PAM information.
-    poDS->SetDescription( poOpenInfo->pszFilename );
-    poDS->TryLoadXML( poOpenInfo->GetSiblingFiles() );
+    poDS->SetDescription(poOpenInfo->pszFilename);
+    poDS->TryLoadXML(poOpenInfo->GetSiblingFiles());
 
     return poDS.release();
 }
@@ -401,15 +399,15 @@ GDALDataset* BASISUDataset::Open(GDALOpenInfo* poOpenInfo)
 /*                            CreateCopy()                              */
 /************************************************************************/
 
-GDALDataset* BASISUDataset::CreateCopy(const char * pszFilename, GDALDataset *poSrcDS,
-                                       int /*bStrict*/, char ** papszOptions,
+GDALDataset *BASISUDataset::CreateCopy(const char *pszFilename,
+                                       GDALDataset *poSrcDS, int /*bStrict*/,
+                                       char **papszOptions,
                                        GDALProgressFunc pfnProgress,
-                                       void * pProgressData)
+                                       void *pProgressData)
 {
-    if( !GDAL_KTX2_BASISU_CreateCopy(pszFilename, poSrcDS,
-                                     false, // bIsKTX2
-                                     papszOptions,
-                                     pfnProgress, pProgressData) )
+    if (!GDAL_KTX2_BASISU_CreateCopy(pszFilename, poSrcDS,
+                                     false,  // bIsKTX2
+                                     papszOptions, pfnProgress, pProgressData))
     {
         return nullptr;
     }
@@ -423,7 +421,7 @@ GDALDataset* BASISUDataset::CreateCopy(const char * pszFilename, GDALDataset *po
 
 void GDALRegister_BASISU()
 {
-    if( GDALGetDriverByName( "BASISU" ) != nullptr )
+    if (GDALGetDriverByName("BASISU") != nullptr)
         return;
 
     GDALDriver *poDriver = new GDALDriver();
@@ -432,14 +430,15 @@ void GDALRegister_BASISU()
     poDriver->SetMetadataItem(GDAL_DCAP_RASTER, "YES");
     poDriver->SetMetadataItem(GDAL_DMD_LONGNAME,
                               "Basis Universal texture format");
-    poDriver->SetMetadataItem( GDAL_DMD_HELPTOPIC, "drivers/raster/basisu.html" );
+    poDriver->SetMetadataItem(GDAL_DMD_HELPTOPIC, "drivers/raster/basisu.html");
     poDriver->SetMetadataItem(GDAL_DMD_EXTENSION, "basis");
     poDriver->SetMetadataItem(GDAL_DMD_CREATIONDATATYPES, "Byte");
 
-    poDriver->SetMetadataItem( GDAL_DCAP_VIRTUALIO, "YES" );
+    poDriver->SetMetadataItem(GDAL_DCAP_VIRTUALIO, "YES");
 
-    poDriver->SetMetadataItem( GDAL_DMD_CREATIONOPTIONLIST,
-       GDAL_KTX2_BASISU_GetCreationOptions(/* bIsKTX2 = */ false).c_str() );
+    poDriver->SetMetadataItem(
+        GDAL_DMD_CREATIONOPTIONLIST,
+        GDAL_KTX2_BASISU_GetCreationOptions(/* bIsKTX2 = */ false).c_str());
 
     poDriver->pfnIdentify = BASISUDataset::Identify;
     poDriver->pfnOpen = BASISUDataset::Open;
