@@ -30,18 +30,16 @@
 #include "ogr_spatialref.h"
 #include "rawdataset.h"
 
+#include <algorithm>
+
 /************************************************************************/
 /* ==================================================================== */
 /*                             ROIPACDataset                            */
 /* ==================================================================== */
 /************************************************************************/
 
-class ROIPACRasterBand;
-
 class ROIPACDataset final : public RawDataset
 {
-    friend class ROIPACRasterBand;
-
     VSILFILE *fpImage;
     VSILFILE *fpRsc;
 
@@ -54,6 +52,8 @@ class ROIPACDataset final : public RawDataset
 
     CPL_DISALLOW_COPY_ASSIGN(ROIPACDataset)
 
+    CPLErr Close() override;
+
   public:
     ROIPACDataset();
     ~ROIPACDataset() override;
@@ -64,7 +64,7 @@ class ROIPACDataset final : public RawDataset
                                int nBandsIn, GDALDataType eType,
                                char **papszOptions);
 
-    void FlushCache(bool bAtClosing) override;
+    CPLErr FlushCache(bool bAtClosing) override;
     CPLErr GetGeoTransform(double *padfTransform) override;
     CPLErr SetGeoTransform(double *padfTransform) override;
 
@@ -77,22 +77,6 @@ class ROIPACDataset final : public RawDataset
     char **GetFileList() override;
 };
 
-/************************************************************************/
-/* ==================================================================== */
-/*                           ROIPACRasterBand                           */
-/* ==================================================================== */
-/************************************************************************/
-
-class ROIPACRasterBand final : public RawRasterBand
-{
-    CPL_DISALLOW_COPY_ASSIGN(ROIPACRasterBand)
-
-  public:
-    ROIPACRasterBand(GDALDataset *poDS, int nBand, VSILFILE *fpRaw,
-                     vsi_l_offset nImgOffset, int nPixelOffset, int nLineOffset,
-                     GDALDataType eDataType, int bNativeOrder);
-};
-
 /************************************************************************/
 /*                           getRscFilename()                           */
 /************************************************************************/
@@ -152,16 +136,37 @@ ROIPACDataset::ROIPACDataset()
 
 ROIPACDataset::~ROIPACDataset()
 {
-    ROIPACDataset::FlushCache(true);
-    if (fpRsc != nullptr && VSIFCloseL(fpRsc) != 0)
+    ROIPACDataset::Close();
+}
+
+/************************************************************************/
+/*                              Close()                                 */
+/************************************************************************/
+
+CPLErr ROIPACDataset::Close()
+{
+    CPLErr eErr = CE_None;
+    if (nOpenFlags != OPEN_FLAGS_CLOSED)
     {
-        CPLError(CE_Failure, CPLE_FileIO, "I/O error");
+        if (ROIPACDataset::FlushCache(true) != CE_None)
+            eErr = CE_Failure;
+
+        if (fpRsc != nullptr && VSIFCloseL(fpRsc) != 0)
+        {
+            eErr = CE_Failure;
+            CPLError(CE_Failure, CPLE_FileIO, "I/O error");
+        }
+        if (fpImage != nullptr && VSIFCloseL(fpImage) != 0)
+        {
+            eErr = CE_Failure;
+            CPLError(CE_Failure, CPLE_FileIO, "I/O error");
+        }
+        CPLFree(pszRscFilename);
+
+        if (GDALPamDataset::Close() != CE_None)
+            eErr = CE_Failure;
     }
-    if (fpImage != nullptr && VSIFCloseL(fpImage) != 0)
-    {
-        CPLError(CE_Failure, CPLE_FileIO, "I/O error");
-    }
-    CPLFree(pszRscFilename);
+    return eErr;
 }
 
 /************************************************************************/
@@ -203,7 +208,7 @@ GDALDataset *ROIPACDataset::Open(GDALOpenInfo *poOpenInfo)
     /* -------------------------------------------------------------------- */
     /*      Load the .rsc information.                                      */
     /* -------------------------------------------------------------------- */
-    char **papszRsc = nullptr;
+    CPLStringList aosRSC;
     while (true)
     {
         const char *pszLine = CPLReadLineL(fpRsc);
@@ -222,7 +227,7 @@ GDALDataset *ROIPACDataset::Open(GDALOpenInfo *poOpenInfo)
             CSLDestroy(papszTokens);
             break;
         }
-        papszRsc = CSLSetNameValue(papszRsc, papszTokens[0], papszTokens[1]);
+        aosRSC.SetNameValue(papszTokens[0], papszTokens[1]);
 
         CSLDestroy(papszTokens);
     }
@@ -230,19 +235,17 @@ GDALDataset *ROIPACDataset::Open(GDALOpenInfo *poOpenInfo)
     /* -------------------------------------------------------------------- */
     /*      Fetch required fields.                                          */
     /* -------------------------------------------------------------------- */
-    if (CSLFetchNameValue(papszRsc, "WIDTH") == nullptr ||
-        CSLFetchNameValue(papszRsc, "FILE_LENGTH") == nullptr)
+    if (aosRSC.FetchNameValue("WIDTH") == nullptr ||
+        aosRSC.FetchNameValue("FILE_LENGTH") == nullptr)
     {
-        CSLDestroy(papszRsc);
         CPL_IGNORE_RET_VAL(VSIFCloseL(fpRsc));
         return nullptr;
     }
-    const int nWidth = atoi(CSLFetchNameValue(papszRsc, "WIDTH"));
-    const int nFileLength = atoi(CSLFetchNameValue(papszRsc, "FILE_LENGTH"));
+    const int nWidth = atoi(aosRSC.FetchNameValue("WIDTH"));
+    const int nFileLength = atoi(aosRSC.FetchNameValue("FILE_LENGTH"));
 
     if (!GDALCheckDatasetDimensions(nWidth, nFileLength))
     {
-        CSLDestroy(papszRsc);
         CPL_IGNORE_RET_VAL(VSIFCloseL(fpRsc));
         return nullptr;
     }
@@ -250,14 +253,13 @@ GDALDataset *ROIPACDataset::Open(GDALOpenInfo *poOpenInfo)
     /* -------------------------------------------------------------------- */
     /*      Create a corresponding GDALDataset.                             */
     /* -------------------------------------------------------------------- */
-    ROIPACDataset *poDS = new ROIPACDataset();
+    auto poDS = cpl::make_unique<ROIPACDataset>();
     poDS->nRasterXSize = nWidth;
     poDS->nRasterYSize = nFileLength;
     poDS->eAccess = poOpenInfo->eAccess;
     poDS->fpRsc = fpRsc;
     poDS->pszRscFilename = CPLStrdup(osRscFilename.c_str());
-    poDS->fpImage = poOpenInfo->fpL;
-    poOpenInfo->fpL = nullptr;
+    std::swap(poDS->fpImage, poOpenInfo->fpL);
 
     /* -------------------------------------------------------------------- */
     /*      Create band information objects.                                */
@@ -286,8 +288,6 @@ GDALDataset *ROIPACDataset::Open(GDALOpenInfo *poOpenInfo)
 #else
         CPLError(CE_Failure, CPLE_NotSupported,
                  "Reading ROI_PAC raw files is not supported yet.");
-        delete poDS;
-        CSLDestroy(papszRsc);
         return nullptr;
 #endif
     }
@@ -328,8 +328,6 @@ GDALDataset *ROIPACDataset::Open(GDALOpenInfo *poOpenInfo)
     }
     else
     { /* Eeek */
-        delete poDS;
-        CSLDestroy(papszRsc);
         return nullptr;
     }
 
@@ -385,46 +383,38 @@ GDALDataset *ROIPACDataset::Open(GDALOpenInfo *poOpenInfo)
     if (bIntOverflow)
     {
         CPLError(CE_Failure, CPLE_AppDefined, "Int overflow occurred.");
-        delete poDS;
-        CSLDestroy(papszRsc);
         return nullptr;
     }
 
-#ifdef CPL_LSB
-    const bool bNativeOrder = true;
-#else
-    const bool bNativeOrder = false;
-#endif
-    poDS->nBands = nBands;
     for (int b = 0; b < nBands; b++)
     {
-        poDS->SetBand(b + 1, new ROIPACRasterBand(poDS, b + 1, poDS->fpImage,
-                                                  nBandOffset * b, nPixelOffset,
-                                                  nLineOffset, eDataType,
-                                                  bNativeOrder));
+        auto poBand = RawRasterBand::Create(
+            poDS.get(), b + 1, poDS->fpImage, nBandOffset * b, nPixelOffset,
+            nLineOffset, eDataType,
+            RawRasterBand::ByteOrder::ORDER_LITTLE_ENDIAN,
+            RawRasterBand::OwnFP::NO);
+        if (!poBand)
+            return nullptr;
+        poDS->SetBand(b + 1, std::move(poBand));
     }
 
     /* -------------------------------------------------------------------- */
     /*      Interpret georeferencing, if present.                           */
     /* -------------------------------------------------------------------- */
-    if (CSLFetchNameValue(papszRsc, "X_FIRST") != nullptr &&
-        CSLFetchNameValue(papszRsc, "X_STEP") != nullptr &&
-        CSLFetchNameValue(papszRsc, "Y_FIRST") != nullptr &&
-        CSLFetchNameValue(papszRsc, "Y_STEP") != nullptr)
+    if (aosRSC.FetchNameValue("X_FIRST") != nullptr &&
+        aosRSC.FetchNameValue("X_STEP") != nullptr &&
+        aosRSC.FetchNameValue("Y_FIRST") != nullptr &&
+        aosRSC.FetchNameValue("Y_STEP") != nullptr)
     {
-        poDS->adfGeoTransform[0] =
-            CPLAtof(CSLFetchNameValue(papszRsc, "X_FIRST"));
-        poDS->adfGeoTransform[1] =
-            CPLAtof(CSLFetchNameValue(papszRsc, "X_STEP"));
+        poDS->adfGeoTransform[0] = CPLAtof(aosRSC.FetchNameValue("X_FIRST"));
+        poDS->adfGeoTransform[1] = CPLAtof(aosRSC.FetchNameValue("X_STEP"));
         poDS->adfGeoTransform[2] = 0.0;
-        poDS->adfGeoTransform[3] =
-            CPLAtof(CSLFetchNameValue(papszRsc, "Y_FIRST"));
+        poDS->adfGeoTransform[3] = CPLAtof(aosRSC.FetchNameValue("Y_FIRST"));
         poDS->adfGeoTransform[4] = 0.0;
-        poDS->adfGeoTransform[5] =
-            CPLAtof(CSLFetchNameValue(papszRsc, "Y_STEP"));
+        poDS->adfGeoTransform[5] = CPLAtof(aosRSC.FetchNameValue("Y_STEP"));
         poDS->bValidGeoTransform = true;
     }
-    if (CSLFetchNameValue(papszRsc, "PROJECTION") != nullptr)
+    if (aosRSC.FetchNameValue("PROJECTION") != nullptr)
     {
         /* ------------------------------------------------------------ */
         /* In ROI_PAC, images are georeferenced either with lat/long or */
@@ -433,24 +423,24 @@ GDALDataset *ROIPACDataset::Open(GDALOpenInfo *poOpenInfo)
         /* bands!                                                       */
         /* ------------------------------------------------------------ */
         OGRSpatialReference oSRS;
-        if (strcmp(CSLFetchNameValue(papszRsc, "PROJECTION"), "LL") == 0)
+        if (strcmp(aosRSC.FetchNameValue("PROJECTION"), "LL") == 0)
         {
-            if (CSLFetchNameValue(papszRsc, "DATUM") != nullptr)
+            if (aosRSC.FetchNameValue("DATUM") != nullptr)
             {
-                oSRS.SetWellKnownGeogCS(CSLFetchNameValue(papszRsc, "DATUM"));
+                oSRS.SetWellKnownGeogCS(aosRSC.FetchNameValue("DATUM"));
             }
             else
             {
                 oSRS.SetWellKnownGeogCS("WGS84");
             }
         }
-        else if (STARTS_WITH(CSLFetchNameValue(papszRsc, "PROJECTION"), "UTM"))
+        else if (STARTS_WITH(aosRSC.FetchNameValue("PROJECTION"), "UTM"))
         {
-            const char *pszZone = CSLFetchNameValue(papszRsc, "PROJECTION") + 3;
+            const char *pszZone = aosRSC.FetchNameValue("PROJECTION") + 3;
             oSRS.SetUTM(atoi(pszZone), TRUE); /* FIXME: north/south? */
-            if (CSLFetchNameValue(papszRsc, "DATUM") != nullptr)
+            if (aosRSC.FetchNameValue("DATUM") != nullptr)
             {
-                oSRS.SetWellKnownGeogCS(CSLFetchNameValue(papszRsc, "DATUM"));
+                oSRS.SetWellKnownGeogCS(aosRSC.FetchNameValue("DATUM"));
             }
             else
             {
@@ -460,20 +450,20 @@ GDALDataset *ROIPACDataset::Open(GDALOpenInfo *poOpenInfo)
         poDS->m_oSRS = oSRS;
         poDS->m_oSRS.SetAxisMappingStrategy(OAMS_TRADITIONAL_GIS_ORDER);
     }
-    if (CSLFetchNameValue(papszRsc, "Z_OFFSET") != nullptr)
+    if (aosRSC.FetchNameValue("Z_OFFSET") != nullptr)
     {
         const double dfOffset =
-            strtod(CSLFetchNameValue(papszRsc, "Z_OFFSET"), nullptr);
+            strtod(aosRSC.FetchNameValue("Z_OFFSET"), nullptr);
         for (int b = 1; b <= nBands; b++)
         {
             GDALRasterBand *poBand = poDS->GetRasterBand(b);
             poBand->SetOffset(dfOffset);
         }
     }
-    if (CSLFetchNameValue(papszRsc, "Z_SCALE") != nullptr)
+    if (aosRSC.FetchNameValue("Z_SCALE") != nullptr)
     {
         const double dfScale =
-            strtod(CSLFetchNameValue(papszRsc, "Z_SCALE"), nullptr);
+            strtod(aosRSC.FetchNameValue("Z_SCALE"), nullptr);
         for (int b = 1; b <= nBands; b++)
         {
             GDALRasterBand *poBand = poDS->GetRasterBand(b);
@@ -484,10 +474,10 @@ GDALDataset *ROIPACDataset::Open(GDALOpenInfo *poOpenInfo)
     /* -------------------------------------------------------------------- */
     /*      Set all the other header metadata into the ROI_PAC domain       */
     /* -------------------------------------------------------------------- */
-    for (int i = 0; papszRsc != nullptr && papszRsc[i] != nullptr; i++)
+    for (int i = 0; i < aosRSC.size(); ++i)
     {
         char **papszTokens = CSLTokenizeString2(
-            papszRsc[i], "=", CSLT_STRIPLEADSPACES | CSLT_STRIPENDSPACES);
+            aosRSC[i], "=", CSLT_STRIPLEADSPACES | CSLT_STRIPENDSPACES);
         if (CSLCount(papszTokens) < 2 || strcmp(papszTokens[0], "WIDTH") == 0 ||
             strcmp(papszTokens[0], "FILE_LENGTH") == 0 ||
             strcmp(papszTokens[0], "X_FIRST") == 0 ||
@@ -505,12 +495,6 @@ GDALDataset *ROIPACDataset::Open(GDALOpenInfo *poOpenInfo)
         poDS->SetMetadataItem(papszTokens[0], papszTokens[1], "ROI_PAC");
         CSLDestroy(papszTokens);
     }
-
-    /* -------------------------------------------------------------------- */
-    /*      Free papszRsc                                                   */
-    /* -------------------------------------------------------------------- */
-    CSLDestroy(papszRsc);
-
     /* -------------------------------------------------------------------- */
     /*      Initialize any PAM information.                                 */
     /* -------------------------------------------------------------------- */
@@ -520,9 +504,9 @@ GDALDataset *ROIPACDataset::Open(GDALOpenInfo *poOpenInfo)
     /* -------------------------------------------------------------------- */
     /*      Check for overviews.                                            */
     /* -------------------------------------------------------------------- */
-    poDS->oOvManager.Initialize(poDS, poOpenInfo->pszFilename);
+    poDS->oOvManager.Initialize(poDS.get(), poOpenInfo->pszFilename);
 
-    return poDS;
+    return poDS.release();
 }
 
 /************************************************************************/
@@ -682,37 +666,36 @@ GDALDataset *ROIPACDataset::Create(const char *pszFilename, int nXSize,
     CPL_IGNORE_RET_VAL(VSIFPrintfL(fp, "%-40s %d\n", "FILE_LENGTH", nYSize));
     CPL_IGNORE_RET_VAL(VSIFCloseL(fp));
 
-    return reinterpret_cast<GDALDataset *>(GDALOpen(pszFilename, GA_Update));
+    return GDALDataset::FromHandle(GDALOpen(pszFilename, GA_Update));
 }
 
 /************************************************************************/
 /*                             FlushCache()                             */
 /************************************************************************/
 
-void ROIPACDataset::FlushCache(bool bAtClosing)
+CPLErr ROIPACDataset::FlushCache(bool bAtClosing)
 {
-    RawDataset::FlushCache(bAtClosing);
+    CPLErr eErr = RawDataset::FlushCache(bAtClosing);
 
     GDALRasterBand *band = (GetRasterCount() > 0) ? GetRasterBand(1) : nullptr;
 
     if (eAccess == GA_ReadOnly || band == nullptr)
-        return;
+        return eErr;
 
     // If opening an existing file in Update mode (i.e. "r+") we need to make
     // sure any existing content is cleared, otherwise the file may contain
     // trailing content from the previous write.
-    CPL_IGNORE_RET_VAL(VSIFTruncateL(fpRsc, 0));
+    bool bOK = VSIFTruncateL(fpRsc, 0) == 0;
 
-    CPL_IGNORE_RET_VAL(VSIFSeekL(fpRsc, 0, SEEK_SET));
+    bOK &= VSIFSeekL(fpRsc, 0, SEEK_SET) == 0;
     /* -------------------------------------------------------------------- */
     /*      Rewrite out the header.                                         */
     /* -------------------------------------------------------------------- */
     /* -------------------------------------------------------------------- */
     /*      Raster dimensions.                                              */
     /* -------------------------------------------------------------------- */
-    CPL_IGNORE_RET_VAL(VSIFPrintfL(fpRsc, "%-40s %d\n", "WIDTH", nRasterXSize));
-    CPL_IGNORE_RET_VAL(
-        VSIFPrintfL(fpRsc, "%-40s %d\n", "FILE_LENGTH", nRasterYSize));
+    bOK &= VSIFPrintfL(fpRsc, "%-40s %d\n", "WIDTH", nRasterXSize) > 0;
+    bOK &= VSIFPrintfL(fpRsc, "%-40s %d\n", "FILE_LENGTH", nRasterYSize) > 0;
 
     /* -------------------------------------------------------------------- */
     /*      Georeferencing.                                                 */
@@ -723,13 +706,12 @@ void ROIPACDataset::FlushCache(bool bAtClosing)
         int iUTMZone = m_oSRS.GetUTMZone(&bNorth);
         if (iUTMZone != 0)
         {
-            CPL_IGNORE_RET_VAL(VSIFPrintfL(fpRsc, "%-40s %s%d\n", "PROJECTION",
-                                           "UTM", iUTMZone));
+            bOK &= VSIFPrintfL(fpRsc, "%-40s %s%d\n", "PROJECTION", "UTM",
+                               iUTMZone) > 0;
         }
         else if (m_oSRS.IsGeographic())
         {
-            CPL_IGNORE_RET_VAL(
-                VSIFPrintfL(fpRsc, "%-40s %s\n", "PROJECTION", "LL"));
+            bOK &= VSIFPrintfL(fpRsc, "%-40s %s\n", "PROJECTION", "LL") > 0;
         }
         else
         {
@@ -742,8 +724,7 @@ void ROIPACDataset::FlushCache(bool bAtClosing)
         {
             if (strcmp(m_oSRS.GetAttrValue("DATUM"), "WGS_1984") == 0)
             {
-                CPL_IGNORE_RET_VAL(
-                    VSIFPrintfL(fpRsc, "%-40s %s\n", "DATUM", "WGS84"));
+                bOK &= VSIFPrintfL(fpRsc, "%-40s %s\n", "DATUM", "WGS84") > 0;
             }
             else
             {
@@ -751,16 +732,16 @@ void ROIPACDataset::FlushCache(bool bAtClosing)
                          "Datum \"%s\" probably not supported in the "
                          "ROI_PAC format, saving it anyway",
                          m_oSRS.GetAttrValue("DATUM"));
-                CPL_IGNORE_RET_VAL(VSIFPrintfL(fpRsc, "%-40s %s\n", "DATUM",
-                                               m_oSRS.GetAttrValue("DATUM")));
+                bOK &= VSIFPrintfL(fpRsc, "%-40s %s\n", "DATUM",
+                                   m_oSRS.GetAttrValue("DATUM")) > 0;
             }
         }
         if (m_oSRS.GetAttrValue("UNIT") != nullptr)
         {
-            CPL_IGNORE_RET_VAL(VSIFPrintfL(fpRsc, "%-40s %s\n", "X_UNIT",
-                                           m_oSRS.GetAttrValue("UNIT")));
-            CPL_IGNORE_RET_VAL(VSIFPrintfL(fpRsc, "%-40s %s\n", "Y_UNIT",
-                                           m_oSRS.GetAttrValue("UNIT")));
+            bOK &= VSIFPrintfL(fpRsc, "%-40s %s\n", "X_UNIT",
+                               m_oSRS.GetAttrValue("UNIT")) > 0;
+            bOK &= VSIFPrintfL(fpRsc, "%-40s %s\n", "Y_UNIT",
+                               m_oSRS.GetAttrValue("UNIT")) > 0;
         }
     }
     if (bValidGeoTransform)
@@ -773,18 +754,18 @@ void ROIPACDataset::FlushCache(bool bAtClosing)
         }
         else
         {
-            CPL_IGNORE_RET_VAL(VSIFPrintfL(fpRsc, "%-40s %.16g\n", "X_FIRST",
-                                           adfGeoTransform[0]));
-            CPL_IGNORE_RET_VAL(VSIFPrintfL(fpRsc, "%-40s %.16g\n", "X_STEP",
-                                           adfGeoTransform[1]));
-            CPL_IGNORE_RET_VAL(VSIFPrintfL(fpRsc, "%-40s %.16g\n", "Y_FIRST",
-                                           adfGeoTransform[3]));
-            CPL_IGNORE_RET_VAL(VSIFPrintfL(fpRsc, "%-40s %.16g\n", "Y_STEP",
-                                           adfGeoTransform[5]));
-            CPL_IGNORE_RET_VAL(VSIFPrintfL(fpRsc, "%-40s %.16g\n", "Z_OFFSET",
-                                           band->GetOffset(nullptr)));
-            CPL_IGNORE_RET_VAL(VSIFPrintfL(fpRsc, "%-40s %.16g\n", "Z_SCALE",
-                                           band->GetScale(nullptr)));
+            bOK &= VSIFPrintfL(fpRsc, "%-40s %.16g\n", "X_FIRST",
+                               adfGeoTransform[0]) > 0;
+            bOK &= VSIFPrintfL(fpRsc, "%-40s %.16g\n", "X_STEP",
+                               adfGeoTransform[1]) > 0;
+            bOK &= VSIFPrintfL(fpRsc, "%-40s %.16g\n", "Y_FIRST",
+                               adfGeoTransform[3]) > 0;
+            bOK &= VSIFPrintfL(fpRsc, "%-40s %.16g\n", "Y_STEP",
+                               adfGeoTransform[5]) > 0;
+            bOK &= VSIFPrintfL(fpRsc, "%-40s %.16g\n", "Z_OFFSET",
+                               band->GetOffset(nullptr)) > 0;
+            bOK &= VSIFPrintfL(fpRsc, "%-40s %.16g\n", "Z_SCALE",
+                               band->GetScale(nullptr)) > 0;
         }
     }
 
@@ -816,10 +797,13 @@ void ROIPACDataset::FlushCache(bool bAtClosing)
             CSLDestroy(papszTokens);
             continue;
         }
-        CPL_IGNORE_RET_VAL(
-            VSIFPrintfL(fpRsc, "%-40s %s\n", papszTokens[0], papszTokens[1]));
+        bOK &= VSIFPrintfL(fpRsc, "%-40s %s\n", papszTokens[0],
+                           papszTokens[1]) > 0;
         CSLDestroy(papszTokens);
     }
+    if (!bOK)
+        eErr = CE_Failure;
+    return eErr;
 }
 
 /************************************************************************/
@@ -872,20 +856,6 @@ char **ROIPACDataset::GetFileList()
     return papszFileList;
 }
 
-/************************************************************************/
-/*                         ROIPACRasterBand()                           */
-/************************************************************************/
-
-ROIPACRasterBand::ROIPACRasterBand(GDALDataset *poDSIn, int nBandIn,
-                                   VSILFILE *fpRawIn, vsi_l_offset nImgOffsetIn,
-                                   int nPixelOffsetIn, int nLineOffsetIn,
-                                   GDALDataType eDataTypeIn, int bNativeOrderIn)
-    : RawRasterBand(poDSIn, nBandIn, fpRawIn, nImgOffsetIn, nPixelOffsetIn,
-                    nLineOffsetIn, eDataTypeIn, bNativeOrderIn,
-                    RawRasterBand::OwnFP::NO)
-{
-}
-
 /************************************************************************/
 /*                        GDALRegister_ROIPAC()                         */
 /************************************************************************/
