@@ -141,7 +141,7 @@ class OGRMapMLWriterDataset final : public GDALPamDataset
     }
     OGRLayer *GetLayer(int idx) override;
 
-    OGRLayer *ICreateLayer(const char *, OGRSpatialReference * = nullptr,
+    OGRLayer *ICreateLayer(const char *, const OGRSpatialReference * = nullptr,
                            OGRwkbGeometryType = wkbUnknown,
                            char ** = nullptr) override;
 
@@ -977,12 +977,12 @@ int OGRMapMLWriterDataset::TestCapability(const char *pszCap)
 /*                           ICreateLayer()                             */
 /************************************************************************/
 
-OGRLayer *OGRMapMLWriterDataset::ICreateLayer(const char *pszLayerName,
-                                              OGRSpatialReference *poSRS,
-                                              OGRwkbGeometryType,
-                                              char ** /* papszOptions */)
+OGRLayer *OGRMapMLWriterDataset::ICreateLayer(
+    const char *pszLayerName, const OGRSpatialReference *poSRSIn,
+    OGRwkbGeometryType, char ** /* papszOptions */)
 {
     OGRSpatialReference oSRS_WGS84;
+    const OGRSpatialReference *poSRS = poSRSIn;
     if (poSRS == nullptr)
     {
         oSRS_WGS84.SetFromUserInput(SRS_WKT_WGS84_LAT_LONG);
